@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
 from sphinxcontrib import spam
 from docutils.parsers.rst.states import Inliner
 
@@ -15,4 +14,4 @@ def test_spam_role():
     ilr = Inliner()
     node = spam.spam_role('spam', u':spam:`あばばばば`',
             u'あばばばば', 123, ilr)[0][0]
-    assert unicode(node) == 'spam! あばばばば spam!'
+    assert unicode(node) == u'spam! あばばばば spam!'
